@@ -7,27 +7,31 @@ use {
         DeviceId,
         Mount,
         read_mounts,
+        ReadOptions,
     },
 };
 
+#[derive(Default)]
 pub struct MountList {
     mounts: Option<Vec<Mount>>,
 }
 
 impl MountList {
-    pub const fn new() -> Self {
-        Self { mounts: None }
-    }
     pub fn clear_cache(&mut self) {
         self.mounts = None;
     }
     /// try to load the mounts if they aren't loaded.
     pub fn load(&mut self) -> Result<&Vec<Mount>, ProgramError> {
         if self.mounts.is_none() {
-            match read_mounts() {
+            let mut options = ReadOptions::default();
+            options.remote_stats(false);
+            match read_mounts(&options) {
                 Ok(mut vec) => {
                     debug!("{} mounts loaded", vec.len());
-                    vec.sort_by_key(|m| u64::MAX - m.size());
+                    vec.sort_by_key(|m| {
+                        let size = m.stats().map_or(0, |s| s.size());
+                        u64::MAX - size
+                    });
                     self.mounts = Some(vec);
                 }
                 Err(e) => {
