@@ -11,8 +11,8 @@ use {
         app::AppContext,
         errors::TreeBuildError,
         git::{
-            GitIgnoreChain,
-            GitIgnorer,
+            IgnoreChain,
+            Ignorer,
             LineStatusComputer,
         },
         path::Directive,
@@ -75,7 +75,7 @@ pub struct TreeBuilder<'c> {
     root_id: BId,
     subpath_offset: usize,
     total_search: bool,
-    git_ignorer: GitIgnorer,
+    git_ignorer: Ignorer,
     line_status_computer: Option<LineStatusComputer>,
     con: &'c AppContext,
     pub matches_max: Option<usize>, // optional hard limit
@@ -92,7 +92,7 @@ impl<'c> TreeBuilder<'c> {
     ) -> Result<TreeBuilder<'c>, TreeBuildError> {
         let mut blines = Arena::new();
         let subpath_offset = path.components().count();
-        let mut git_ignorer = time!(GitIgnorer::default());
+        let mut git_ignorer = time!(Ignorer::default());
         let root_ignore_chain = git_ignorer.root_chain(&path);
         let line_status_computer = if options.filter_by_git_status || options.show_git_file_info {
             time!(
@@ -202,10 +202,8 @@ impl<'c> TreeBuilder<'c> {
                 }
             }
         }
-        if file_type.is_file() {
-            if !has_match {
-                return None;
-            }
+        if file_type.is_file() && !has_match {
+            return None;
         }
         if self.options.only_folders && !file_type.is_dir() {
             if !file_type.is_symlink() {
@@ -241,7 +239,7 @@ impl<'c> TreeBuilder<'c> {
             direct_match,
             score,
             nb_kept_children: 0,
-            git_ignore_chain: GitIgnoreChain::default(),
+            git_ignore_chain: IgnoreChain::default(),
             special_handling,
         })
     }
@@ -358,6 +356,9 @@ impl<'c> TreeBuilder<'c> {
                     if child.has_match {
                         nb_lines_ok += 1;
                     }
+                    if self.options.max_depth.map_or(false, |max| child.depth > max) {
+                        break;
+                    }
                     if child.can_enter() {
                         next_level_dirs.push(child_id);
                     }
@@ -436,9 +437,7 @@ impl<'c> TreeBuilder<'c> {
         let mut remove_queue: BinaryHeap<SortableBId> = BinaryHeap::new();
         for id in &out_blines[1..] {
             let bline = &self.blines[*id];
-            if bline.has_match
-                && bline.nb_kept_children == 0
-                && (bline.depth > 1 || self.trim_root)
+            if bline.has_match && bline.nb_kept_children == 0 && (bline.depth > 1 || self.trim_root)
             {
                 remove_queue.push(SortableBId {
                     id: *id,
@@ -472,15 +471,7 @@ impl<'c> TreeBuilder<'c> {
         bid: BId,
     ) -> Result<TreeLine, TreeBuildError> {
         let bline = &self.blines[bid];
-        let line_type = TreeLineType::new(&bline.path, &bline.file_type);
-        let unlisted = bline
-            .children
-            .as_ref()
-            .map_or(0, |children| children.len() - bline.next_child_idx);
-        let metadata =
-            fs::symlink_metadata(&bline.path).map_err(|_| TreeBuildError::FileNotFound {
-                path: bline.path.to_string_lossy().to_string(),
-            })?;
+        let path = bline.path.clone();
         let subpath = if bline.depth == 0 {
             bline.path.to_string_lossy().to_string()
         } else {
@@ -493,38 +484,23 @@ impl<'c> TreeBuilder<'c> {
                 .to_string_lossy()
                 .to_string()
         };
-        let name = bline
-            .path
-            .file_name()
-            .and_then(|os_str| os_str.to_str())
-            .unwrap_or("")
-            .replace('\n', "");
-        let icon = self.con.icons.as_ref().map(|icon_plugin| {
-            let extension = TreeLine::extension_from_name(&name);
-            let double_extension =
-                extension.and_then(|_| TreeLine::double_extension_from_name(&name));
-            icon_plugin.get_icon(&line_type, &name, double_extension, extension)
-        });
-
-        Ok(TreeLine {
-            bid,
-            parent_bid: bline.parent_id,
-            left_branches: vec![false; bline.depth as usize].into_boxed_slice(),
-            depth: bline.depth,
-            icon,
-            name,
+        let unlisted = bline
+            .children
+            .as_ref()
+            .map_or(0, |children| children.len() - bline.next_child_idx);
+        TreeLineBuilder {
+            path,
             subpath,
-            path: bline.path.clone(),
-            line_type,
-            has_error: bline.has_error,
-            nb_kept_children: bline.nb_kept_children as usize,
+            id: bid.index(),
+            parent_id: bline.parent_id.map(|bid| bid.index()),
+            depth: bline.depth,
             unlisted,
+            nb_kept_children: bline.nb_kept_children as usize,
+            has_error: bline.has_error,
             score: bline.score,
             direct_match: bline.direct_match,
-            sum: None,
-            metadata,
-            git_status: None,
-        })
+        }
+        .build(self.con)
     }
 
     /// make a tree from the builder's specific structure
@@ -550,8 +526,10 @@ impl<'c> TreeBuilder<'c> {
                 }
             }
         }
+        let next_line_id = lines.iter().map(|line| line.id).max().unwrap_or(0) + 1;
         let mut tree = Tree {
-            lines: lines.into_boxed_slice(),
+            lines,
+            next_line_id,
             selection: 0,
             options: self.options.clone(),
             scroll: 0,
@@ -566,7 +544,7 @@ impl<'c> TreeBuilder<'c> {
             tree.git_status = ComputationResult::NotComputed;
             // it would make no sense to keep only files having a git status and
             // not display that type
-            for line in tree.lines.iter_mut() {
+            for line in &mut tree.lines {
                 line.git_status = computer.line_status(&line.path);
             }
         }
@@ -582,13 +560,12 @@ impl<'c> TreeBuilder<'c> {
         total_search: bool,
         dam: &Dam,
     ) -> Result<Tree, TreeBuildError> {
-        self.gather_lines(total_search, dam).map(|blines_ids| {
-            debug!("blines before trimming: {}", blines_ids.len());
-            if !self.total_search {
-                self.trim_excess(&blines_ids);
-            }
-            self.take_as_tree(&blines_ids)
-        })
+        let blines_ids = self.gather_lines(total_search, dam)?;
+        debug!("blines before trimming: {}", blines_ids.len());
+        if !self.total_search {
+            self.trim_excess(&blines_ids);
+        }
+        Ok(self.take_as_tree(&blines_ids))
     }
 
     pub fn build_paths<F>(
