@@ -1,8 +1,10 @@
 mod bid;
 mod bline;
+mod build_report;
 mod builder;
 
 pub use {
-    builder::TreeBuilder,
     bid::BId,
+    builder::TreeBuilder,
+    build_report::BuildReport,
 };
