@@ -6,7 +6,7 @@ use {
         path::PathAnchor,
     },
     regex::Regex,
-    ahash::AHashMap,
+    rustc_hash::FxHashMap,
     std::{
         path::PathBuf,
     },
@@ -129,10 +129,10 @@ impl InvocationParser {
         }
     }
 
-    pub fn parse(&self, args: &str) -> Option<AHashMap<String, String>> {
+    pub fn parse(&self, args: &str) -> Option<FxHashMap<String, String>> {
         self.args_parser.as_ref()
             .map(|r| {
-                let mut map = AHashMap::default();
+                let mut map = FxHashMap::default();
                 if let Some(input_cap) = r.captures(args) {
                     for name in r.capture_names().flatten() {
                         if let Some(c) = input_cap.name(name) {
