@@ -81,8 +81,8 @@ impl VerbStore {
         self.add_internal(input_go_word_right).no_doc();
 
         // arrow keys bindings
-        self.add_internal(back).with_key(key!(left));
-        self.add_internal(open_stay).with_key(key!(right));
+        self.add_internal(back);
+        self.add_internal(open_stay);
         self.add_internal(line_down).with_key(key!(down)).with_key(key!('j'));
         self.add_internal(line_up).with_key(key!(up)).with_key(key!('k'));
 
@@ -328,6 +328,8 @@ impl VerbStore {
         self.add_internal(toggle_git_file_info).with_shortcut("gf");
         self.add_internal(toggle_git_status).with_shortcut("gs");
         self.add_internal(toggle_root_fs).with_shortcut("rfs");
+        self.add_internal(set_max_depth);
+        self.add_internal(unset_max_depth);
         self.add_internal(toggle_hidden)
             .with_key(key!(alt-h))
             .with_shortcut("h");
@@ -474,7 +476,7 @@ impl VerbStore {
             }
             external_execution
         };
-        let execution = match (execution, internal, external, cmd) {
+        let mut execution = match (execution, internal, external, cmd) {
             // old definition with "execution": we guess whether it's an internal or
             // an external
             (Some(ep), None, None, None) => {
@@ -513,6 +515,13 @@ impl VerbStore {
                 return Ok(());
             }
         };
+        if let Some(refresh_after) = vc.refresh_after {
+            if let VerbExecution::External(external_execution) = &mut execution {
+                external_execution.refresh_after = refresh_after;
+            } else {
+                warn!("refresh_after is only relevant for external commands");
+            }
+        }
         let description = vc
             .description
             .clone()
@@ -567,7 +576,7 @@ impl VerbStore {
         prefix: &str,
         sel_info: SelInfo<'_>,
         panel_state_type: Option<PanelStateType>,
-    ) -> PrefixSearchResult<'v, &Verb> {
+    ) -> PrefixSearchResult<'v, &'v Verb> {
         self.search(prefix, Some(sel_info), true, panel_state_type)
     }
 
@@ -575,7 +584,7 @@ impl VerbStore {
         &'v self,
         prefix: &str,
         panel_state_type: Option<PanelStateType>,
-    ) -> PrefixSearchResult<'v, &Verb> {
+    ) -> PrefixSearchResult<'v, &'v Verb> {
         self.search(prefix, None, true, panel_state_type)
     }
 
@@ -599,7 +608,7 @@ impl VerbStore {
         sel_info: Option<SelInfo>,
         short_circuit: bool,
         panel_state_type: Option<PanelStateType>,
-    ) -> PrefixSearchResult<'v, &Verb> {
+    ) -> PrefixSearchResult<'v, &'v Verb> {
         let mut found_index = 0;
         let mut nb_found = 0;
         let mut completions: Vec<&str> = Vec::new();
